@@ -9,24 +9,6 @@ from threading import local
 
 from .result import Result
 
-# All threads will have a context which is
-# managed by a stack of Context objects. As
-# a thread establish additional context using
-# 'with' statements, the stack will push/grow. As
-# 'with' blocks end, the stack will pop/shrink.
-context = local()
-
-context.stack = []
-context.default_oc_path = os.getenv("OPENSHIFT_CLIENT_PYTHON_DEFAULT_OC_PATH", "oc")  # Assume oc is in $PATH by default
-context.default_kubeconfig_path = os.getenv("OPENSHIFT_CLIENT_PYTHON_DEFAULT_CONFIG_PATH", None)
-context.default_api_server = os.getenv("OPENSHIFT_CLIENT_PYTHON_DEFAULT_API_SERVER", None)
-context.default_token = None  # Does not support environment variable injection to discourage this insecure practice
-context.default_ca_cert_path = os.getenv("OPENSHIFT_CLIENT_PYTHON_DEFAULT_CA_CERT_PATH", None)
-context.default_project = os.getenv("OPENSHIFT_CLIENT_PYTHON_DEFAULT_PROJECT", None)
-context.default_options = {}
-context.default_loglevel = os.getenv("OPENSHIFT_CLIENT_PYTHON_DEFAULT_OC_LOGLEVEL", None)
-context.default_skip_tls_verify = os.getenv("OPENSHIFT_CLIENT_PYTHON_DEFAULT_SKIP_TLS_VERIFY", None)
-
 # Provides defaults for ssh_client context instantiations
 DEFAULT_SSH_HOSTNAME = os.getenv("OPENSHIFT_CLIENT_PYTHON_DEFAULT_SSH_HOSTNAME", None)
 DEFAULT_SSH_USERNAME = os.getenv("OPENSHIFT_CLIENT_PYTHON_DEFAULT_SSH_USERNAME", None)
@@ -605,9 +587,29 @@ def timeout(seconds):
     return c
 
 
-root_context = Context()
-root_context.set_timeout(MASTER_TIMEOUT)
+class ThreadLocalContext(local):
+    def __init__(self):
+        self.default_oc_path = os.getenv("OPENSHIFT_CLIENT_PYTHON_DEFAULT_OC_PATH", "oc")  # Assume oc is in $PATH by default
+        self.default_kubeconfig_path = os.getenv("OPENSHIFT_CLIENT_PYTHON_DEFAULT_CONFIG_PATH", None)
+        self.default_api_server = os.getenv("OPENSHIFT_CLIENT_PYTHON_DEFAULT_API_SERVER", None)
+        self.default_token = None  # Does not support environment variable injection to discourage this insecure practice
+        self.default_ca_cert_path = os.getenv("OPENSHIFT_CLIENT_PYTHON_DEFAULT_CA_CERT_PATH", None)
+        self.default_project = os.getenv("OPENSHIFT_CLIENT_PYTHON_DEFAULT_PROJECT", None)
+        self.default_options = {}
+        self.default_loglevel = os.getenv("OPENSHIFT_CLIENT_PYTHON_DEFAULT_OC_LOGLEVEL", None)
+        self.default_skip_tls_verify = os.getenv("OPENSHIFT_CLIENT_PYTHON_DEFAULT_SKIP_TLS_VERIFY", None)
 
-# Ensure stack always has at least one member to simplify getting last
-# with [-1]
-context.stack = [root_context]
+        root_context = Context()
+        root_context.set_timeout(MASTER_TIMEOUT)
+
+        # Ensure stack always has at least one member to simplify getting last
+        # with [-1]
+        self.stack = [root_context]
+
+
+# All threads will have a context which is
+# managed by a stack of Context objects. As
+# a thread establish additional context using
+# 'with' statements, the stack will push/grow. As
+# 'with' blocks end, the stack will pop/shrink.
+context = ThreadLocalContext()
